glados.slack_classes.views module — GLaDOS 0.0.1-alpha1 documentation

# glados.slack_classes.views module

class `glados.slack_classes.views.` `Home`(*, blocks=None)

  Bases: `slack.web.classes.JsonObject`

  `add_block`(block)
    Parameters

      block (`Block`) –

  `attributes` = {'home'}
  `to_dict`(*args)

    Extract this object as a JSON-compatible, Slack-API-valid dictionary

    Parameters

      *args – Any specific formatting args (rare; generally not required)

    Raises

      SlackObjectFormationError if the object was not valid –

    Return type

      `dict`